@@ -6,9 +6,9 @@ Type annotations for finspace-data service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_finspace_data.literals import ChangeType
+    from mypy_boto3_finspace_data.literals import ChangeTypeType
 
-    data: ChangeType = "APPEND"
+    data: ChangeTypeType = "APPEND"
     ```
 """
 import sys
@@ -20,18 +20,18 @@ else:
 
 
 __all__ = (
-    "ChangeType",
-    "ChangesetStatus",
-    "ErrorCategory",
-    "FormatType",
-    "SourceType",
-    "locationType",
+    "ChangeTypeType",
+    "ChangesetStatusType",
+    "ErrorCategoryType",
+    "FormatTypeType",
+    "SourceTypeType",
+    "locationTypeType",
 )
 
 
-ChangeType = Literal["APPEND", "MODIFY", "REPLACE"]
-ChangesetStatus = Literal["FAILED", "PENDING", "RUNNING", "STOP_REQUESTED", "SUCCESS"]
-ErrorCategory = Literal[
+ChangeTypeType = Literal["APPEND", "MODIFY", "REPLACE"]
+ChangesetStatusType = Literal["FAILED", "PENDING", "RUNNING", "STOP_REQUESTED", "SUCCESS"]
+ErrorCategoryType = Literal[
     "A_user_recoverable_error_has_occurred",
     "An_internal_error_has_occurred",
     "Cancelled",
@@ -41,6 +41,6 @@ ErrorCategory = Literal[
     "The_inputs_to_this_request_are_invalid",
     "The_system_temporarily_lacks_sufficient_resources_to_process_the_request",
 ]
-FormatType = Literal["CSV", "JSON", "PARQUET", "XML"]
-SourceType = Literal["S3"]
-locationType = Literal["INGESTION", "SAGEMAKER"]
+FormatTypeType = Literal["CSV", "JSON", "PARQUET", "XML"]
+SourceTypeType = Literal["S3"]
+locationTypeType = Literal["INGESTION", "SAGEMAKER"]
